==> kmyfirewall-trinity_3.5.13.2.orig.tar.xz: kmyfirewall-trinity-3.5.13.2/kmyfirewall/kmfdisclaimer.cpp <==
/***************************************************************************
 begin                : Tue Mar 19 2002
 copyright            : (C) 2002 by Christian Hubinger
 email                : a9806056@unet.univie.ac.at
***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include "kmfdisclaimer.h"
#include "kmyfirewall.h" 
// kde
#include <kconfig.h>
#include <ksimpleconfig.h>
#include <kurl.h>
#include <kdebug.h>
#include <kstandarddirs.h>
#include <klocale.h>
#include <kapplication.h> 
// qt
#include <tqmessagebox.h>
#include <tqfile.h>
#include <tqstring.h>
#include <tqcheckbox.h>

KMFDisclaimer::KMFDisclaimer( TQWidget *parent, const char *name, bool modal, WFlags fl ) : KMyFirewallDisclaimer( parent, name, modal, fl ) {}
KMFDisclaimer::~KMFDisclaimer() {}

void KMFDisclaimer::accept() {
	KConfig * _config = kapp->config();
	_config->setGroup( "STARTUP" );
	if ( c_show->isChecked() ) {
		_config->writeEntry( "show_disclaimer", "false" );
		_config->sync();
	} else {
		_config->writeEntry( "show_disclaimer", "true" );
		_config->sync();
	}
	TQDialog::accept();
}

#include "kmfdisclaimer.moc"

==> kmyfirewall-trinity_14.1.1.orig.tar.xz: kmyfirewall-trinity-14.1.1/kmyfirewall/kmfdisclaimer.cpp <==
/***************************************************************************
 begin                : Tue Mar 19 2002
 copyright            : (C) 2002 by Christian Hubinger
 email                : a9806056@unet.univie.ac.at
***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include "kmfdisclaimer.h"
#include "kmyfirewall.h" 
// kde
#include <tdeconfig.h>
#include <ksimpleconfig.h>
#include <kurl.h>
#include <kdebug.h>
#include <kstandarddirs.h>
#include <tdelocale.h>
#include <tdeapplication.h> 
// qt
#include <tqmessagebox.h>
#include <tqfile.h>
#include <tqstring.h>
#include <tqcheckbox.h>

KMFDisclaimer::KMFDisclaimer( TQWidget *parent, const char *name, bool modal, WFlags fl ) : KMyFirewallDisclaimer( parent, name, modal, fl ) {}
KMFDisclaimer::~KMFDisclaimer() {}

void KMFDisclaimer::accept() {
	TDEConfig * _config = kapp->config();
	_config->setGroup( "STARTUP" );
	if ( c_show->isChecked() ) {
		_config->writeEntry( "show_disclaimer", "false" );
		_config->sync();
	} else {
		_config->writeEntry( "show_disclaimer", "true" );
		_config->sync();
	}
	TQDialog::accept();
}

#include "kmfdisclaimer.moc"
